# CHANGELOG

This is a manually generated log to track changes to the repository for each release. 
Each section should include general headers such as **Implemented enhancements** 
and **Merged pull requests**. 

The versions coincide with releases on pypi.

## [0.0.x](https://github.com/vsoch/dinosaur-dilemma/tree/master) (0.0.x)
 - tweaks to graphical interface (0.0.12)
 - adding graphical interface (0.0.11)
 - initial release with basic classes and prototype (0.0.1)
